#
# spec file for package os-update
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _distconfdir}
  %define _distconfdir %{_sysconfdir}
%endif

Name:           os-update
VCS: https://src.suse.de/SLFO-pool/os-update#a58190a16f2351ca4eb18234e6414591e0f85ba869ce393c33122e316534f7b3
Version:        1.21+git.20241206
Release:        160000.1.3
Summary:        Updates the system regularly to stay current and safe
License:        GPL-2.0-or-later
URL:            https://github.com/openSUSE/os-update
Source:         os-update-%{version}.tar.xz
Source99:       os-update-rpmlintrc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  go-md2man
BuildRequires:  pkgconfig
BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools
BuildRequires:  pkgconfig(systemd)
Requires:       lsof
Recommends:     rebootmgr
Recommends:     systemd-status-mail
BuildArch:      noarch
%if 0%{?suse_version} >= 1500
Requires:       zypper-needs-restarting
%endif
%if 0%{?suse_version} >= 1600
Requires:       zypp-boot-plugin >= 0.0.4
%endif

%description
Service to keep an OS update to date and secure. It is run by a
systemd.timer daily and can inform rebootmgrd that the update
requires a reboot.

%package -n systemd-status-mail
Summary:        Send a mail if a systemd.timer fails and/or succeeds
%sysusers_requires
%if 0%{?suse_version} >= 1500
Requires:       (/usr/sbin/sendmail or mailx)
Suggests:       mailx
%else
Requires:       mailx
%endif

%description -n systemd-status-mail
systemd-mail-status is called by systemd-status-mail@.service if the
service is configured for the OnFailure and/or OnSuccess case of a
systemd unit. It sends an email to a configureable address with the name
of the service, the hostname and the output of
"systemctl status --full <service>".

%prep
%setup -q

%build
./autogen.sh
%configure
%if 0%{?suse_version} < 1500
  %define make_build %{__make} -O %{?_smp_mflags}
%endif
%make_build
%sysusers_generate_pre systemd/systemd-status-mail.conf systemd-status-mail systemd-status-mail.conf

%install
%make_install
install -m 644 -D etc/default/systemd-status-mail %{buildroot}%{_distconfdir}/default/systemd-status-mail

%pre
%service_add_pre os-update.timer

%post
%service_add_post os-update.timer

%preun
%service_del_preun os-update.timer

%postun
%service_del_postun os-update.timer

%pre -n systemd-status-mail -f systemd-status-mail.pre

%files
%license COPYING
%doc README.md
%dir %{_datadir}/os-update
%{_datadir}/os-update/os-update.conf
%{_libexecdir}/os-update
%{_prefix}/lib/systemd/system/os-update.service
%{_prefix}/lib/systemd/system/os-update.timer
%{_mandir}/man8/os-update.8%{?ext_man}

%files -n systemd-status-mail
%license COPYING
%if 0%{?suse_version} < 1550
%config(noreplace) %{_sysconfdir}/default/systemd-status-mail
%else
%{_distconfdir}/default/systemd-status-mail
%endif
%{_libexecdir}/systemd-status-mail
%{_prefix}/lib/systemd/system/systemd-status-mail@.service
%{_prefix}/lib/systemd/system-generators/status-mail-generator.sh
%{_mandir}/man8/systemd-status-mail.8%{?ext_man}
%dir %{_datadir}/systemd-status-mail
%{_datadir}/systemd-status-mail/status-mail.conf
%{_sysusersdir}/systemd-status-mail.conf

%changelog
* Fri Dec  6 2024 kukuk@suse.com
- Update to version 1.21+git.20241206:
  * Release version 1.21
  * Fix check for service restarts
* Wed Dec  4 2024 kukuk@suse.com
- Update to version 1.20+git.20241204:
  * Release version 1.20
  * Switch from pandoc to go-md2man
  * Add option to ignore services at all
* Mon Nov 11 2024 kukuk@suse.com
- Update to version 1.19+git.20241111:
  * Release version 1.19
  * Only provide application defaults as comments
  * Don't try to restart dbus-broker, use soft-reboot
  * Don't hardcode path of rebootmgrctl
* Wed Nov  6 2024 kukuk@suse.com
- Update to version 1.18+git.20241106:
  * Release version 1.18
  * Move vendor config to /usr/share/os-update
  * Unify indentation style
* Mon Oct  7 2024 kukuk@suse.com
- Update to version 1.17+git.20241007:
  * Refresh before dup
  * Always refresh
* Wed May  8 2024 kukuk@suse.com
- Update to version 1.17
  - Implement soft-reboot support for non restartable services
* Mon Mar 11 2024 kukuk@suse.com
- Update to version 1.16
  - Enhance logging for soft-reboot tracking
* Thu Jan 18 2024 kukuk@suse.com
- Update to version 1.15
  - Add systemd generator for systemd-status-mail
  - Add own user for status-mail service
* Fri Jan  5 2024 georg.pfuetzenreuter@suse.com
- Do not overwrite os-update.conf on Leap
* Fri Nov 24 2023 kukuk@suse.com
- Update to version 1.14
  - Fix check if rebootmgrctl is installed
* Thu Nov 23 2023 kukuk@suse.com
- Update to version 1.13
  - Skip restart of virtlockd by default
* Thu Oct  5 2023 kukuk@suse.com
- Update to version 1.12
  - Add support for systemd soft-reboot
* Mon May  8 2023 kukuk@suse.com
- Use suse_version instead of sle_version
* Fri Apr 28 2023 kukuk@suse.com
- Adjust URL to openSUSE github repo
* Fri Apr 28 2023 vetter@physik.uni-wuerzburg.de
- Fix things not available in SLE12:
  - Do not require zypper-needs-restarting
  - Require mailx since conditional requires are not available in SLE12
  - define make_build macro
* Thu Apr 27 2023 kukuk@suse.com
- Update to Version 1.11
  - Add LOG_TAG
  - Fix reboottrigger for SLES12
* Tue Apr 25 2023 georg.pfuetzenreuter@suse.com
- Require lsof
* Thu Jan 19 2023 kukuk@suse.com
- Update to Version 1.10
  - Fix check if reboot is required
  - Improve/fix check if systemd needs to be restarted
* Fri Jan 13 2023 kukuk@suse.com
- Update to Version 1.9
  - Minimal support for SLE12 (os-update)
  - From address now configureable (systemd-status-mail)
  - Include error messages of systemctl, too (systemd-status-mail)
* Wed Dec 21 2022 kukuk@suse.com
- Update to Version 1.8
  - Allow to specify additional options for mailx
* Wed Dec 21 2022 kastl@b1-systems.de
- if sysconfdir is being used on older SLES/Leap versions,
  mark the config file as %%config(noreplace)
* Mon Dec 19 2022 kukuk@suse.com
- Update to Version 1.7
  - Fix detection of running rebootmgrd
  - Add SERVICES_TRIGGERING_REBOOT (#2)
* Mon Dec  5 2022 kukuk@suse.com
- Update to version 1.6
  - Restart systemd if necessary
* Thu Nov 24 2022 kukuk@suse.com
- Update to version 1.5
  - Restart udev after update by default
  - Support REBOOT_CMD="none"
* Fri Nov 11 2022 kukuk@suse.com
- Update to version 1.4.2
  - Fixes for openSUSE Leap
  - Add docu URLs to service files
* Thu Nov 10 2022 kukuk@suse.com
- Update to version 1.4.1
  - Increase limit of lines from log in status mail to 500
  - Fix syntax error in systemd-status-mail manual page source
* Mon Nov  7 2022 kukuk@suse.com
- Update to version 1.4
  - Provide service to send mails about systemd service status
* Fri Nov  4 2022 kukuk@suse.com
- Update to version 1.3
  - Restart services: don't restart os-update itself during update
* Thu Nov  3 2022 kukuk@suse.com
- Require zypper-needs-restarting
* Mon Oct 31 2022 kukuk@suse.com
- Update to version 1.2
  - Restart updated services
* Thu Oct 27 2022 kukuk@suse.com
- Update to version 1.1
  - Update documentation
  - Add openSUSE Leap support
* Mon Jun 13 2022 kukuk@suse.com
- Update to version 1.0
  - First public release
  - Update documentation
* Thu Oct  8 2020 kukuk@suse.com
- Remove debug output
* Fri Sep 25 2020 kukuk@suse.com
- Initial version
